# pyjr

An assistance package for ETL, model development and validation.

[![PyPI](https://img.shields.io/pypi/v/pyjr?color=brightgreen&logoColor=lightgrey)](https://pypi.org/project/pyjr/)

## Description
*Project is not complete.*

## Getting Started
*Project is not complete.*

### Installing
The package can be accessed via pip install.

    pip install pyjr

### Future Work
* Plot classes have not been vetted. (All plots, besides barchart, are functional)
* Documentation of classes and functions.
* Update to TimeSeries, Tuning and Features.
* Test all model classes and functions.
* Add to self-contained functions.

### Changelog
* 0.0.1 - *Initial Release*
  * This serves as a quick release to utilize the basic functionality.
* 0.0.2 - *Working Release*
  * This release has passed a cursory review. 
* 0.0.3 - *Plot Release*
  * This release adds improved plotting capabilities.
